/*
 * $Id: fqd.h,v 1.5 2002/12/02 03:58:00 dwalters Exp $
 *
 * fqd.h - Sets up two TPU channels to decode a pair of
 *         quadrature encoded signals using the TPU function FQD.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    fqd.h
 *
 *  @brief   FQD TPU functions.
 *
 *  This file contains the global function prototypes and 
 *  data structures for the Fast Quadrature Decoder (FQD) functionality of 
 *  the <b>libtpu</b> library.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/fqd.h></b> and link <b>libtpu.a</b>.
 *
 *  @ingroup libtpu
 */

#ifndef __TPU_FQD_H
#define __TPU_FQD_H

#include <68332/types.h>
#include <68332/tpu.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Reads the signed 16-bit integer representing the current encoder
 * count.  The first call to this function initializes the two channels
 * for quadrature decoding using FQD.
 * 
 * @param  primaryChannel    Pointer to first TPUChannel returned from 
 *                           tpu_request_channel().
 *                           
 * @param  secondaryChannel  Pointer to second TPUChannel returned from
 *                           tpu_request_channel().
 *                           
 * @return                   Quadrature decoder output count.
 * 
 * <b>Note:</b> The <b>secondaryChannel</b> must be the next higher TPU 
 * channel adjacent to the <b>primaryChannel</b>.
 */
int16 fqd (
	TPUChannel* primaryChannel, 
	TPUChannel* secondaryChannel
);

#ifdef __cplusplus
}
#endif

#endif	// #ifndef __TPU_FQD_H
