/*
 * $Id: fqddi.h,v 1.5 2002/12/02 03:58:00 dwalters Exp $
 *
 * fqddi.h - Sets up a TPU channel to provide a
 *           discrete input using the TPU function FQD.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    fqddi.h
 *
 *  @brief   FQDDI TPU functions.
 *
 *  This file contains the global function prototypes and 
 *  data structures for the Fast Quadrature Decoder Discrete Input 
 *  (FQDDI) functionality of the <b>libtpu</b> library.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/fqddi.h></b> and link <b>libtpu.a</b>.
 *
 *  @ingroup libtpu
 */

#ifndef __TPU_FQDDI_H
#define __TPU_FQDDI_H

#include <68332/types.h>
#include <68332/tpu.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Reads the logic state on a TPU channel pin.  The first call to
 * this function initializes the pin for discrete input using FQD.
 * 
 * @param  handle  The pointer to a TPUChannel returned from 
 *                 tpu_request_channel().
 *
 * @return         The state of the pin.
 */
bool fqddi (
	TPUChannel* handle
);

#ifdef __cplusplus
}
#endif

#endif	// #ifndef __TPU_FQDDI_H
