/*
 * $Id: isr.h,v 1.6 2002/12/02 20:19:07 dwalters Exp $
 *
 * Copyright (C) 2001 Mike Panetta 
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    isr.h
 *
 *  @brief   Functions to support Interrupt Service Routines.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/isr.h></b> and link <b>libbase.a</b>.
 *  
 *  @ingroup libbase
 */

/**
 *  @defgroup   libbase  libbase
 *
 *  @brief   	MotoRobots base.
 *
 */

#ifndef __ISR_h
#define	__ISR_h

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Installs an Interrupt Service Routine.
 *
 * @param  vecNum  The interrupt vector number.
 * @param  func    A pointer to the function that handles the interrupt 
 *                 (the ISR). The ISR must be a parameterless function
 *                 with no return value (void). 
 */
void install_isr(int vecNum, void (*func)() );

/**
 * Sets the interrupt priority mask.  
 *
 * @param  level  Levels are 1-7.  Only interrupts
 * at a higher level than the mask are serviced.  Level 7 cannot be
 * unmaksed.
 *
 */
int set_int_level(int level);

#ifdef __cplusplus
}
#endif

#endif
