/*
 * $Id: adc.h,v 1.1 2003/10/30 03:18:31 dasmith Exp $
 *
 * adc.h - This file contains the definitions of the low level
 * functions used to access the analog-to-digital converter.
 *
 * Copyright (C) 2003 David Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    adc.h
 *
 *  @brief   Low-level analog-to-digital conversion functions.
 *
 *  This file contains the global function prototypes and 
 *  data structures for the low level ADC support in <b>libadc</b>.
 *  
 *  To use the functions defined in this file, 
 *  <b>include <68332/mrm/adc.h></b> and link <b>libadc.a</b>.
 *  
 *  @ingroup libadc
 */

/**
 *  @defgroup   libadc   libadc
 *
 *  @brief   	Analog to Digital Conversion.
 *
 *  The <b>libadc</b> library contains functions
 *  to read from the MAX118 ADC on the MRM.
 *
 */

#ifndef __ADC_H
#define __ADC_H

#include <68332/types.h>

/**
 * ADC channel numbers
 */
typedef enum
{
  ADC_CHANNEL0 = 0,
  ADC_CHANNEL1,
  ADC_CHANNEL2,
  ADC_CHANNEL3,
  ADC_CHANNEL4,
  ADC_CHANNEL5,
  ADC_CHANNEL6,
  ADC_CHANNEL7
} adc_channel_t;

/* Start of C function declarations */
#ifdef __cplusplus
extern "C" {
#endif

/** 
 * Read all eight ADC channels.
 * Note: The adc[] array must contain at least
 * eight array locations. Only the first eight
 * locations in adc[] are modified.
 *
 * @param  adc[]  An array of eight bytes to contain the
 *                analog to digital conversion results.
 *
 * @return        0 on success, nonzero on failure.
 */
int adc_all(uint8 adc[]);

/** 
 * Read an ADC channel.
 *
 * @param  channel_num  Specifies which channel to convert.
 *
 * @return              The eight bit analog to digital
 *                      conversion result.
 */
uint8 adc_channel(adc_channel_t channel_num);


#ifdef __cplusplus
}
#endif

#endif	/* __ADC_H */
