/*
 * $Id: lcd.h,v 1.4 2002/12/02 20:19:20 dwalters Exp $
 * Useful routines for driving the MRM LCD interface.
 *
 * Copyright (C) 2001 Martin Calsyn
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    lcd.h
 *
 *  @brief   LCD driver functions for the MRM.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/mrm/lcd.h></b> and link <b>liblcd.a</b>.
 *  
 *  @ingroup liblcd
 */

/**
 *  @defgroup   liblcd	liblcd
 *
 *  @brief   	LCD display driver for the MRM.
 *
 */

#ifndef __LCD_H__
#define __LCD_H__

#include <sys/types.h>
#include <68332/types.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Initialize LCD display.
 * 
 * @param  rows         The number of lines the display has.
 * @param  columns      The number of horizontal characters the display has.
 * @param  font         Select the main (0) or alternate (1) font.
 * @param  fourbitmode  Set this TRUE if the LCD only supports 4-bit IO.
 */
int lcd_init (
	uint8 rows, 
	uint8 columns, 
	uint8 font, 
	bool fourbitmode
);

/** 
 * Turn the display on or off.
 *
 * @param  on  Set to TRUE to turn the display on.
 */
void lcd_display_enable (
	bool on
);

/** 
 * Control the appearance of the cursor.
 *
 * @param  on        Set to TRUE to make the cursor visible.
 * @param  flashing  Set to TRUE to make the cursor flash.
 */
void lcd_cursor (
	bool on, 
	bool flashing
);

/** 
 * Clear the display.
 */
void lcd_clear ();

/** 
 * Home the cursor.  The next character output will appear at 0,0 
 */
void lcd_home ();

/** 
 * Position the cursor.
 *
 * @param  x  The row (zero-based).
 * @param  y  The column (zero-based).
 */
void lcd_gotoxy (
	uint8 x, 
	uint8 y
);

/**
 * Send output to the LCD at the current cursor location.
 *
 * This function uses the same syntax as <b>printf()</b>.
 */
void lcd_printf (
	char *pszPattern, 
	...
);

/**
 * Display a string on the LCD at the current cursor location.
 */
void lcd_write_string (
	char *string
);

#ifdef __cplusplus
}
#endif

#endif	/* #ifndef __LCD_H__ */

