/*
 * $Id: led.h,v 1.3 2002/12/02 03:58:02 dwalters Exp $
 * Useful routines for driving the MRM LEDs
 *
 * Copyright (C) 2001 Martin Calsyn
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    led.h
 *
 *  @brief   LED driver functions for the MRM.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/mrm/led.h></b> and link <b>libled.a</b>.
 *
 *  @ingroup libled
 */

/**
 *  @defgroup   libled	libled
 *
 *  @brief   	LED driver functions for the MRM.
 *
 */

#ifndef __LED_H__
#define __LED_H__

/** 
 * Enumerates the two LEDs on board the MRM.
 */
typedef enum {
  RedLED = 0,
  GreenLED = 1,
} LED_COLOR_T;

#ifdef __cplusplus
extern "C" {
#endif

/** Initialize LED driver */
void led_init(void);

/** Turn LED on */
void led_on(LED_COLOR_T color);

/** Turn LED off */
void led_off(LED_COLOR_T color);

/** Toggle state of an LED */
void led_toggle(LED_COLOR_T color);

#ifdef __cplusplus
}
#endif

#endif  /* #ifndef __LED_H__ */

