/*
 * $Id: qompulse.h,v 1.1 2003/10/30 02:17:06 dasmith Exp $
 *
 * qompulse.h - Sets up a TPU channel to output a one-shot
 *              pulse using the TPU function QOM.
 *
 * Copyright (C) 2003 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    qompulse.h
 *
 *  @brief   QOMPULSE TPU functions.
 *
 *  This file contains the global function prototypes and 
 *  data structures for the Queued Output Module Pulse 
 *  (QOMPULSE) functionality of the <b>libtpu</b> library.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/qompulse.h></b> and link <b>libtpu.a</b>.
 *
 *  @ingroup libtpu
 */

#ifndef __TPU_QOMPULSE_H
#define __TPU_QOMPULSE_H

#include <68332/types.h>
#include <68332/tpu.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Outputs a one-shot pulse on a TPU channel. The first call to
 * this function initializes the pin for pulse output using QOM.
 * 
 * @param  handle       The pointer to a TPUChannel returned from 
 *                      tpu_request_channel().
 *                  
 * @param  pulseLevel   The logic level of the pulse to output.
 * 
 * @param  pulseLength  The duration of the one-shot pulse output.
 * 
 * <b>pulseLength</b> is expressed in units of TCR1 ticks.
 */
void qompulse (
	TPUChannel* handle, 
	bool pulseLevel,
	uint16 pulseLength
);

#ifdef __cplusplus
}
#endif

#endif	// #ifndef __TPU_QOMPULSE_H
