/*
 * $Id: qompwm.h,v 1.5 2002/12/02 03:58:00 dwalters Exp $
 *
 * qompwm.h - Sets up a TPU channel to provide a
 *            PWM signal using the TPU function QOM.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    qompwm.h
 *
 *  @brief   QOMPWM TPU functions.
 *
 *  This file contains the global function prototypes and 
 *  data structures for the Queued Output Module Pulse-Width 
 *  Modulation (QOMPWM) functionality of the <b>libtpu</b> library.
 *
 *  To use the functions defined in this file, 
 *  <b>include <68332/qompwm.h></b> and link <b>libtpu.a</b>.
 *
 *  @ingroup libtpu
 */

#ifndef __TPU_QOMPWM_H
#define __TPU_QOMPWM_H

#include <68332/types.h>
#include <68332/tpu.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Outputs a PWM waveform on a TPU channel. The first call
 * to this function initializes the pin for PWM using QOM.
 * 
 * @param  handle   The pointer to a TPUChannel returned from 
 *                  tpu_request_channel().
 *                  
 * @param  hi_time  The high time of the PWM signal.
 * 
 * @param  lo_time  The low time of the PWM signal.
 * 
 * <b>hi_time</b> and <b>lo_time</b> are expressed in units of TCR1 ticks.
 */
void qompwm (
	TPUChannel* handle, 
	uint16 hi_time, 
	uint16 lo_time
);

#ifdef __cplusplus
}
#endif

#endif	// #ifndef __TPU_QOMPWM_H
