/*
 * $Id: qsm.h,v 1.4 2002/12/02 20:19:08 dwalters Exp $
 *
 * Copyright (C) 2001 Doug Chapman
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

/**
 *
 *  @file    qsm.h
 *
 *  @brief   QSM functions.
 *
 *  This file contains the global function prototypes 
 *  for QSM support in <b>libqsm</b>.
 *  
 *  To use the functions defined in this file, 
 *  <b>include <68332/qsm.h></b> and link <b>libqsm.a</b>.
 *  
 *  @ingroup libqsm
 */

/**
 *  @defgroup   libqsm	libqsm
 *
 *  @brief   	Queued Serial Module.
 *
 */

#ifndef __QSM_H__
#define __QSM_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Initialize asynchronous serial communications.
 *
 * @param  baud  Baud rate.
 */
void sciinit (
	long baud
);

/**
 * Check if there's a character waiting to be read that has been
 * received via the serial port.
 *
 * @return  Nonzero if there is a character waiting to be read.
 */
int havebyte(void);

/**
 * Read a character that has been received via the serial port.
 *
 * @return  The received byte.
 */
char inbyte(void);

/**
 * Transmits a character via the serial port.
 *
 * @param  tx  The byte to transmit.
 */
void outbyte (
	char tx
);

/**
 * Checks whether the serial port is currently transmitting a byte.
 *
 * @return  Nonzero if the serial port is still transmitting.
 */
int sendingbyte(void);

#ifdef __cplusplus
}
#endif

#endif
