/*
 * base.c
 *
 * This file is primarily to keep the linker happy when not linking
 * with libbcc.a.  The gnu version of libbcc.a (from the newlib package)
 * defines outbyte, inbyte, and havebyte to be the cpu32bug system calls
 * which are not always available.  For the MotoRobots project those
 * are re-defined in libqsm.a.  If we were to still link with libbcc.a
 * we would have multiple definitions of those.
 *
 * If we do _not_ link with libbcc.a we end up with missing symbols
 * from libc.a.  We must define the needed stuff from libbcc  here (most
 * as just dummy targets).
 *
 * The write and read implementations were taken nearly verbatim
 * from the newlib package.
 */

int outbyte(char);
int inbyte(void);

/*
 * write -- write bytes to the serial port. Ignore fd, since
 *          stdout and stderr are the same. Since we have no filesystem,
 *          open will only return an error.
 */
int write(int fd, char *buf, int nbytes)
{
    int i;

    for (i = 0; i < nbytes; i++) {
	if (*(buf + i) == '\n') {
	    outbyte('\r');
	}
	outbyte(*(buf + i));
    }
    return (nbytes);
}

/*
 * read  -- read bytes from the serial port. Ignore fd, since
 *          we only have stdin.
 */
int read(int fd, char *buf, int nbytes)
{
    int i = 0;

    for (i = 0; i < nbytes; i++) {
	*(buf + i) = inbyte();
	if ((*(buf + i) == '\r') || (*(buf + i) == '\n')) {
	    *(buf + i) = '\n';
	    outbyte('\r');
	    outbyte('\n');
	    return i + 1;
	} else
	    outbyte(*(buf + i));
    }
    return (i);
}

int isatty(void)
{
    return 0;
}
int close(void)
{
    return 0;
}
int fstat(void)
{
    return 0;
}
int lseek(void)
{
    return 0;
}
