#include <68332/isr.h>
#include <68332/regs.h>
#include "status_reg.h"

/* Next 2 vars were added by MWP */
extern long vector_start[];  /* Vector base address from Linker script */

static void (*cHandlerFunc[255])() = {0};

void interrupt_handler(void);
void cHandler();

/* 
 * A function to allow us to modify the 
 * vector table base address.
 */
void set_vtable_base(void * base_address)
{
	SET_VBR((unsigned int)base_address);
}
void install_isr(int vecNum, void (*func)() )
{
	/*
	** On first pass, load the vector table with a common
	** assembly language handler. This will in turn call our
	** specified 'c' language handler...
	** MWP: Only do this if we are not using CPU32BUG, so we
	** can preserve the debugger vectors.
	*/
#ifndef WITHCPU32BUG
	static char fp = 1;

	if( fp )
	{
		short i;
		long *vectorPtr = vector_start;

		/*
		** Load all vectors, skipping the reset program counter
		** and stack pointer.
		*/
		for( i=2; i<256; i++ )
		{
			vectorPtr[i] = (long)interrupt_handler;
		}
		fp = 0;

	}
#else  /* WITHCPU32BUG is defined */
	vector_start[vecNum] = (long)interrupt_handler;
#endif

	/*
	** Now install our 'c' handler in the function table.
	*/
	cHandlerFunc[vecNum] = func;
}

asm ("
	.TEXT
	.ALIGN 2 
	.GLOBL interrupt_handler

	/*
	** Note the 0x42 constant is the number of bytes into the stack to
	** obtain the vector offset. This constant is determined by the
	** number and size of the registers pushed onto the stack by the
	** MOVEM instruction.
	*/
interrupt_handler:
	MOVEM.L %D0-%D7/%A0-%A6,%SP@-   /* Save all regs */
    CLR.L %D0                       /* Clear high bits of D0 */
	MOVE.W (0x42,%A7),%D0			/* Grab the vector offset from the stack frame */
	LSR.W #2,%D0					/* Shift to get the vector number */
    
    LEA cHandlerFunc,%A0
    MOVE.L (%A0,%D0.L*4),%A0        /* Grab the pointer to the C function */
    TST.L %A0
    JBEQ .NoHandler                 /* Branch if pointer is NULL */

    MOVE.L %D0,-(%SP)               /* Push vector number on the stack as optional parameter */
    JSR (%A0)                       /* Call the C handler */
    ADDQ.L #4,%SP                   /* Clean up stack */

.NoHandler:
	
    MOVEM.L %SP@+,%D0-%D7/%A0-%A6	/* Restore regs */
	RTE								/* Return from exception */
");


/*
 * the following variables are used to pass data between the C parts
 * and the asm parts.
 */
status_reg_t status_reg;

/*
 * set_int_level
 *
 * Sets the interrupt priority mask.  Levels are 1-7.  Only interrupts
 * at a higher level than the mask are serviced.  Level 7 cannot be
 * unmaksed.
 *
 */
int set_int_level(int level){

    /*
     * NOTE!! this will need to be changed when we go with
     * multi threaded functionality!
     */

    if (level < 0 || level > 7)
	return -1;

    /* get the current value of the status reg */
    asm ("move.w %sr, status_reg");
    status_reg.BITS.IP = level;
    asm ("move.w status_reg, %sr");

    return 0;
}

