// $Id: gbcam.S,v 1.5 2002/11/25 18:45:05 dwalters Exp $
//
// Assembly language code for the gbcam library.
// See http://www.seattlerobotics.org/encoder/200205/gbcam.html for more details
//
// Copyright (C) 2001 Dafydd Walters
// dwalters@users.sourceforge.net 
//
// This library is distributed under the terms of the GNU Lesser General
// Public License (LGPL).  You should have received a copy of the
// license along with this library (LGPL.txt); if not, write to
// the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA  02111-1307  USA

  .title "gbcam code for MRM"

#include <68332/asm.h>

// The following constants may be changed if you are connecting
// the camera to the MRM using ports or pins other than the
// default configuration.  However, beware that certain pins
// have a special purpose during reset, so for example, it is
// not possible to use Port F, bit 0 as an input (e.g. for
// the camera READ signal) since it is the MODCLK configuration
// pin of the 68332.

#define CamVOUT 0xF00000    // camera A/D converter (port 0)
#define CamPort 0xFFFA11    // camera data port (port E)
#define CamDDR  0xFFFA15    // camera data direction register (port E)
#define CamREAD 0           // READ bit position (MRM input)
#define CamXCK  1           // XCK bit position (MRM output)
#define CamXRST 2           // RESET/XRST bit position (MRM output)
#define CamLOAD 3           // LOAD bit position (MRM output)
#define CamSIN  4           // SIN bit position (MRM output)
#define CamSTRT 5           // START bit position (MRM output)

  .align 2

// Image dimension constants

#define HEIGHT  123         // image height
#define WIDTH   128         // image width
#define IMGSIZE 15744       // size of image in pixels

  .data

// Camera Registers.  See the M64282FP data sheet for details.

  .global SYM(gbcam_registers)
SYM(gbcam_registers):
  .byte  0x00   // Z1-Z0, O5-O0
  .byte  0x04   // N, VH1-VH0, G4-G0
shutter:
  .byte  0x0A   // C17-C10            ; this value modified by gbcam_exposure
  .byte  0xFF   // C07-C00            ; this value modified by gbcam_exposure
  .byte  0x01   // P7-P0
  .byte  0x00   // M7-M0
  .byte  0x01   // X7-X0
  .byte  0x07   // E3-E0, I, V2-V0


  .bss

// Image capture buffer

  .global SYM(gbcam_imageBuffer)
SYM(gbcam_imageBuffer):
  .space IMGSIZE, 0


  .text

// Send Reset signal to the camera. A1 is modified.

reset:
  lea   CamPort,a1
  bset  #CamXCK,(a1)
  bclr  #CamXCK,(a1)
  bclr  #CamXRST,(a1)
  bset  #CamXCK,(a1)
  bset  #CamXRST,(a1)
  bclr  #CamXCK,(a1)
  rts


/////////////////////////////////////////////////
// Initialize I/O.

  .global SYM (gbcam_init)

SYM (gbcam_init):

  link.w  a6,#0

  move.l  a1,-(sp)      // Preserve a1

  lea     CamDDR,a1     // Initialize data direction directions
  bclr    #CamREAD,(a1) // input
  bset    #CamSTRT,(a1) // output
  bset    #CamXCK,(a1)  // output
  bset    #CamXRST,(a1) // output
  bset    #CamLOAD,(a1) // output
  bset    #CamSIN,(a1)  // output

  lea     CamPort,a1    // Initialize output bit values
  bclr    #CamSTRT,(a1) // 0
  bclr    #CamXCK,(a1)  // 0
  bset    #CamXRST,(a1) // 1
  bclr    #CamLOAD,(a1) // 0
  bclr    #CamSIN,(a1)  // 0

  move.l  (sp)+,a1      // Restore a1

  unlk    a6

  rts


/////////////////////////////////////////////////////////////
// Take a picture and store the image at gbcam_imageBuffer. 

  .global SYM (gbcam_shoot)

SYM (gbcam_shoot):

  link.w  a6,#0

  move.l  d5,-(sp)
  move.l  d4,-(sp)
  move.l  d3,-(sp)
  move.l  d2,-(sp)
  move.l  d1,-(sp)

  move.l  a5,-(sp)
  move.l  a4,-(sp)
  move.l  a3,-(sp)
  move.l  a2,-(sp)
  move.l  a1,-(sp)
  move.l  a0,-(sp)
  
  bsr     reset                 // reset camera
  bsr     setcam                // set camera registers

  lea     gbcam_imageBuffer,a0
  bsr     capture               // expose image

  move.l  (sp)+,a0
  move.l  (sp)+,a1
  move.l  (sp)+,a2
  move.l  (sp)+,a3
  move.l  (sp)+,a4
  move.l  (sp)+,a5

  move.l  (sp)+,d1
  move.l  (sp)+,d2
  move.l  (sp)+,d3
  move.l  (sp)+,d4
  move.l  (sp)+,d5

  unlk    a6

  rts


// Reset camera and setup camera registers according to values stored
// in gbcam_registers.  Register A1, D0 and D1 are modified.

setcam:
  move.w  #0x000,d0
  or.b    (gbcam_registers+0),d0
  bsr     send
  move.w  #0x100,d0
  or.b    (gbcam_registers+1),d0
  bsr     send
  move.w  #0x200,d0
  or.b    (gbcam_registers+2),d0
  bsr     send
  move.w  #0x300,d0
  or.b    (gbcam_registers+3),d0
  bsr     send
  move.w  #0x400,d0
  or.b    (gbcam_registers+4),d0
  bsr     send
  move.w  #0x500,d0
  or.b    (gbcam_registers+5),d0
  bsr     send
  move.w  #0x600,d0
  or.b    (gbcam_registers+6),d0
  bsr     send
  move.w  #0x700,d0
  or.b    (gbcam_registers+7),d0
  bsr     send
  rts


// Capture picture to A0
// On exit, registers A0, A1, A2, D0, D1, D2 and D3 are modified.

capture:
  lea     CamPort,a1      // point to camera I/O lines
  lea     CamVOUT,a2      // and analog signal port
  bset    #CamSTRT,(a1)   // signal start of capture
  bset    #CamXCK,(a1)
  bclr    #CamXCK,(a1)
  bclr    #CamSTRT,(a1)
  move.b  (a1),d2         // value for XCK=0

// D2 and D3 will be stored to (a1) to clock the camera. Any other
// command sequence would result in a read and a write cycle.

capture3:
  bset    #CamXCK,(a1)    // wait for exposure time
  btst    #CamREAD,(a1)
  bne     capture2
  move.b  d2,(a1)         // XCK=0
  bra     capture3

capture2:
  move.b  (a1),d3         // value for XCK=1
  move.w  #IMGSIZE-1,d1   // number of bytes to transfer

  move.b  d2,(a1)         // XCK=0
  move.b  d3,(a1)         // XCK=1

  move.b  (a2),(a0)       // read and discard from ADC (first read selects ADC channel)

  move.b  d2,(a1)         // XCK=0
  move.b  d3,(a1)         // XCK=1

  move.b  (a2),(a0)       // read and discard from ADC (second read converts)

  move.l  #0,d0

capture1:
  move.b  d3,(a1)         // XCK=1
  move.b  (a2),d0
  move.b  d0,(a0)+        // store pixel data in buffer (third read = result)
  move.b  d2,(a1)         // XCK=0
  dbf     d1,capture1
  rts


// Send the command and address in D0 to the camera. Bit field is:
// xxxxxAAA DDDDDDDD.  Registers A1, D0 and D1 are modified.

send:
  move.w  #10,d1          // 11 bits to send
  lea     CamPort,a1

send1:
  bclr    #CamXCK,(a1)
  btst    #10,d0          // go MSB to LSB
  beq     send0   
  bset    #CamSIN,(a1)    // send a one to the camera
  bra     send2
send0:  
  bclr    #CamSIN,(a1)    // send a zero to camera

send2:
  bset    #CamXCK,(a1)
  lsl     #1,d0
  dbf     d1,send1
  
  bset    #CamLOAD,(a1)
  bclr    #CamXCK,(a1)
  bclr    #CamLOAD,(a1)

  rts
