/*
 * $Id: _lcd.h,v 1.3 2002/10/03 01:22:16 dwalters Exp $
 *
 * Copyright (C) 2001 Martin R. Calsyn
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include "68332/mrm/lcd.h"
#include "stdarg.h"

#define LCD_BASE 0xf00800

typedef struct {
  uint8 CONTROL;
  uint8 DATA;
} LCD_T;

typedef struct {
  bool displayOn;
  bool cursorOn;
  bool cursorFlashing;
  bool fourBitMode;
  uint8 iRows;
  uint8 iCols;
  uint8 ix;
  uint8 iy;
  char buffer[4][40];
} LCDSTATE_T;

extern LCD_T *LCD;
extern LCDSTATE_T g_LCDState;

// Clear the display
#define LCDCMD_CLEAR		0x01

// Home the cursor
#define LCDCMD_HOME		0x02

// set cursor to move, or move and shift, automatically with each char
#define LCDCMD_CURSORMV		0x06
#define LCDCMD_CURSORMV_SHIFT	0x07

#define LCDCMD_DISPLAY_ON       0x0c
#define LCDCMD__WITH_CURSOR     0x02
#define LCDCMD__WITH_BLINK	0x01
#define LCDCMD_DISPLAY_OFF      0x08

// cursor movement and shifting
#define LCDCMD_CURSOR_LEFT	0x10
#define LCDCMD_CURSOR_RIGHT	0x14
#define LCMCMD_SHIFT_LEFT	0x18
#define LCDCMD_SHIFT_RIGHT	0x1c

// function setup
#define LCDCMD_SETUP		0x20
#define LCDCMD_SETUP__8BIT	0x10
#define LCDCMD_SETUP__4BIT	0x00
#define LCDCMD_SETUP__1LINE	0x00
#define LCDCMD_SETUP__2LINE	0x08
#define LCDCMD_SETUP__FONT0	0x00
#define LCDCMD_SETUP__FONT1	0x40

// set cg ram address - addr goes in the low six bits
#define LCDCMD_SETCGADDR	0x40

// set dd ram address - addr goes in the low seven bits
#define LCDCMD_SETDDADDR	0x80
#define LCDCMD__DDLINE0		0x00
#define LCDCMD__DDLINE1		0x40
#define LCDCMD__DDLINE2		0x14
#define LCDCMD__DDLINE3		0x54

// reading the busy flag...
//   read with rs=0 bit 7 is the busy flag, 
//      bits 6:0 are the current cg or dd addr
// writing character data
//   write with rs=1 and bits 7:0 as the character data
// reading character data
//   read with rs=1.  Bits 7:0 will be the character data
#define LCD_BUSY_FLAG		0x80

void lcd_write_cmd(uint8 val);
void lcd_write_data(char val);

