/*
 * $Id: lcd_init.c,v 1.2 2002/10/03 01:22:16 dwalters Exp $
 *
 * Copyright (C) 2001 Martin R. Calsyn
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include "68332/mrm/lcd.h"
#include "_lcd.h"

LCD_T *LCD = (LCD_T*)LCD_BASE;
LCDSTATE_T g_LCDState;

/*
 * Function: lcd_init
 * Description: Initialize the lcd subsystem
 * Parameters:
 *    uint8 iRows - number of rows in the display
 *    uint8 iCols - number of columns in the display
 *    bool fourbits - does this display require four-bit access?
 */
int lcd_init(uint8 iRows, uint8 iCols, uint8 font, bool fourbits)
{
  uint8 cmd;

  g_LCDState.iRows = iRows;
  g_LCDState.iCols = iCols;
  g_LCDState.cursorOn = FALSE;
  g_LCDState.cursorFlashing = FALSE;
  g_LCDState.fourBitMode = fourbits;

  memset(g_LCDState.buffer,' ',sizeof(g_LCDState.buffer));

  if (g_LCDState.fourBitMode)
    cmd = LCDCMD_SETUP|LCDCMD_SETUP__4BIT;
  else
    cmd = LCDCMD_SETUP|LCDCMD_SETUP__8BIT;

  if (iRows>1)
    cmd |= LCDCMD_SETUP__2LINE;

  switch (font) {
  default:
  case 0:
    cmd |= LCDCMD_SETUP__FONT0;
    break;
  case 1:
    cmd |= LCDCMD_SETUP__FONT1;
    break;
  }

  lcd_write_cmd(cmd);
  lcd_write_cmd(cmd);
  lcd_write_cmd(cmd);

  lcd_clear();
  lcd_display_enable(TRUE);
  lcd_write_cmd(LCDCMD_CURSORMV);

  return 1;
}

