/*
 * $Id: lcd_writestring.c,v 1.3 2002/10/03 01:22:16 dwalters Exp $
 *
 * Copyright (C) 2001 Martin R. Calsyn
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <string.h> // for memmove
#include "68332/mrm/lcd.h"
#include "_lcd.h"

/*
 * Function: lcd_write_string
 * Description: write a C string to the LCD
 * Parameters:
 *    char *string - the char string to be written to the lcd
 * Returns:
 *    void
 */
void lcd_write_string(char *string) 
{
  char *p;
  int i,j;
  int temp_x, temp_y;

  for (p=string ; *p ; ++p) {
    switch (*p) {
    case '\n':
      g_LCDState.ix = 0;
      g_LCDState.iy++;
      lcd_gotoxy(g_LCDState.ix,g_LCDState.iy);
      break;
    case '\f':
      lcd_clear();
      lcd_home();
      break;
    default:
      break;
    }
    if (*p!='\n' && *p!='\f') {
      if (g_LCDState.ix > (g_LCDState.iCols-1)) {
	g_LCDState.ix = 0;
	g_LCDState.iy++;
	lcd_gotoxy(g_LCDState.ix,g_LCDState.iy);
      }
      if (g_LCDState.iy > (g_LCDState.iRows - 1)) {
	// adjust and save the x and y value
	temp_x = g_LCDState.ix;
	temp_y = g_LCDState.iRows - 1;

	// clear the display
	lcd_write_cmd(LCDCMD_CLEAR);
	
	// scroll the display up one line and write out n-1 lines
	for (i=0 ; i<(g_LCDState.iRows-1) ; ++i) {
	  memmove(&g_LCDState.buffer[i][0],
		  &g_LCDState.buffer[i+1][0],
		  g_LCDState.iCols);
	  lcd_gotoxy(0,i);
	  for (j=0 ; j<g_LCDState.iCols ; ++j) {
	    //s_achBuffer[i][j] = s_achBuffer[i+1][j];
	    lcd_write_data(g_LCDState.buffer[i][j]);
	  }
	}
	// clear the last line
	memset(&g_LCDState.buffer[g_LCDState.iRows-1][0],' ',g_LCDState.iCols);

	// restore the x and y value
	g_LCDState.ix = temp_x;
	g_LCDState.iy = temp_y;	
	lcd_gotoxy(g_LCDState.ix,g_LCDState.iy);
      }
      // write the next character
      lcd_write_data(*p);
      // remember that char for scrolling
      g_LCDState.buffer[g_LCDState.iy][g_LCDState.ix] = *p;
      // advance the cursor
      g_LCDState.ix++;
    }
  }
}

