/*
 * $Id: led.c,v 1.2 2002/10/03 01:22:16 dwalters Exp $
 *
 * Copyright (C) 2001 Martin R. Calsyn
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include "../../../libsim/68332/sim_regs.h"
#include "68332/mrm/led.h"

/* Don't force inclusion of libsim for the couple of bits we need */
static SIM_T *SIM = (SIM_T *)SIM_BASE;

/*
 * Function: led_init
 * Description: initialize MRM leds
 * Returns: void
 * Parameters: none
 */
void led_init(void) 
{
  SIM->PORTC.BITS.PC4 = 1;
  SIM->PORTC.BITS.PC5 = 1;
  SIM->CSPAR1.BITS.CS7PA = 0;
  SIM->CSPAR1.BITS.CS8PA = 0;
}

/*
 * Function: led_on
 * Description: light an LED
 * Returns: void
 * Returns: the color of led to light
 */
void led_on(LED_COLOR_T color) 
{
  switch(color) {
    case RedLED:
      SIM->PORTC.BITS.PC5 = 0;
      break;
    case GreenLED:
      SIM->PORTC.BITS.PC4 = 0;
      break;
    default:
      break;
  }
}

void led_off(LED_COLOR_T color) 
{
  switch(color) {
    case RedLED:
      SIM->PORTC.BITS.PC5 = 1;
      break;
    case GreenLED:
      SIM->PORTC.BITS.PC4 = 1;
      break;
    default:
      break;
  }
}

void led_toggle(LED_COLOR_T color) 
{
  switch(color) {
    case RedLED:
      SIM->PORTC.BITS.PC5 ^= 1;
      break;
    case GreenLED:
      SIM->PORTC.BITS.PC4 ^= 1;
      break;
    default:
      break;
  }
}
