/*
 * $Id: qsm_regs.h,v 1.3 2003/11/19 03:45:48 dasmith Exp $
 * Register definitions for the 68332 queued serial module.
 *
 * Copyright (C) 2001 Doug Chapman 
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#ifndef __QSM_REGS_H__
#define __QSM_REGS_H__

/*
 * Note, all register definitions use the following convention:
 *
 *	typedef union {
 *		struct {
 *			word <bit group name> : <number of bits>
 *			word <bit group name> : <number of bits>
 *			...
 *			word <bit group name> : <number of bits>
 *			(note, total bits should = 8/16 for byte/word)
 *		} BITS;
 *		word FULLWORD;
 *	} name_t;
 *
 * This allows access to certain bits within a word as a structure
 * member.  This limits the need for bitmasks and bit shifts.  The
 * union allows the full word (FULLWORD) to be accessed as well.
 */

typedef unsigned short int word;
typedef unsigned char byte;

#define QSM_BASE (0xfffffc00L)

typedef union {
    struct {
	word STOP:1;		/* low power stop mode enable */
	word FRZ1:1;		/* FREEZE assertion response */
	word FRZ0:1;		/* not implemented */
	word UNUSED1:5;
	word SUPV:1;		/* supervisor/unrestricted data space */
	word UNUSED0:3;
	word IARB:4;		/* interrupt arbitration ID */
    } BITS;
    word FULLWORD;
} QSMCR_T;

typedef union {
    struct {
	word unused:16;		/* factory test only */
    } BITS;
    word FULLWORD;
} QTEST_T;

typedef union {
    struct {
	byte UNUSED:2;
	byte ILQSP:3;		/* INTERRUPT LEVEL FOR QSPI */
	byte ILSC:3;		/* INTERRUPT LEVEL FOR SCI */
    } BITS;
    byte FULLWORD;
} QILR_T;

typedef union {
    struct {
	byte INTV:8;		/* INTERRUPT VECTOR NUMBER */
    } BITS;
    byte FULLWORD;
} QIVR_T;

typedef union {
    struct {
	word UNUSED:3;
	word SCBR:13;		/* SCI BAUD RATE */
    } BITS;
    word FULLWORD;
} SCCR0_T;

typedef union {
    struct {
	word UNUSED:1;
	word LOOPS:1;		/* loop mode */
	word WOMS:1;		/* wired-or mode for SCI pins */
	word ILT:1;
	word PT:1;
	word PE:1;
	word M:1;
	word WAKE:1;
	word TIE:1;
	word TCIE:1;
	word RIE:1;
	word ILIE:1;
	word TE:1;
	word RE:1;
	word RWU:1;
	word SBK:1;		/* SEND BREAK */
    } BITS;
    word FULLWORD;
} SCCR1_T;

typedef union {
    struct {
	word UNUSED:7;
	word TDRE:1;
	word TC:1;
	word RDRF:1;
	word RAF:1;
	word IDLE:1;
	word OR:1;
	word NF:1;
	word FE:1;
	word PF:1;
    } BITS;
    word FULLWORD;
} SCSR_T;

typedef union {
    struct {
	word UNUSED:8;
	word DATA:8;
    } BITS;
    word FULLWORD;
} SCDR_T;

typedef union {
    struct {
	word UNUSED:8;
	word DATA:8;
    } BITS;
    word FULLWORD;
} PORTQS_T;

typedef union {
    struct {
	byte PA6:1;
	byte PA5:1;
	byte PA4:1;
	byte PA3:1;
	byte UNUSED:1;
	byte PA1:1;
	byte PA0:1;
    } BITS;
    byte FULLWORD;
} PQSPAR_T;

typedef union {
    struct {
	byte PIN7:1;
	byte PIN6:1;
	byte PIN5:1;
	byte PIN4:1;
	byte PIN3:1;
	byte PIN2:1;
	byte PIN1:1;
	byte PIN0:1;
    } BITS;
    byte FULLWORD;
} DDRQS_T;

typedef union {
    struct {
	word MSTR:1;		/* MASTER/SLAVE MODE SELECT */
	word WOMQ:1;		/* WIRED-OR MODE */
	word BITS:4;		/* bits per transfer */
	word CPOL:1;		/* CLOCK POLARITY */
	word CPHA:1;
	word SPBR:8;
    } BITS;
    word FULLWORD;
} SPCR0_T;

typedef union {
    struct {
	word SPE:1;		/* qspi ENABLE */
	word DSCLK:7;		/* DELAY BEFORE SCK */
	word DTL:8;		/* LENGTH OF DELAY AFTER TRANSFER */
    } BITS;
    word FULLWORD;
} SPCR1_T;

typedef union {
    struct {
	word SPIFIE:1;
	word WRTN:1;
	word WRTO:1;
	word UNUSED:1;
	word ENDQP:4;
	word UNUSED1:4;
	word NEWQP:4;
    } BITS;
    word FULLWORD;
} SPCR2_T;

typedef union {
    struct {
	byte UNUSED:5;
	byte LOOPQ:1;
	byte HMIE:1;
	byte HALT:1;
    } BITS;
    byte FULLWORD;
} SPCR3_T;


typedef union {
    struct {
	byte SPIF:1;
	byte MODF:1;
	byte HALTA:1;
	byte UNUSED:1;
	byte CPTQP:4;
    } BITS;
    byte FULLWORD;
} SPSR_T;


typedef union {
    struct {
	byte CONT:1;
	byte BITSE:1;
	byte DT:1;
	byte DSCK:1;
	byte PCS3:1;
	byte PCS2:1;
	byte PCS1:1;
	byte PCS0:1;
    } BITS;
    byte FULLWORD;
} CR_T;


typedef struct {
    QSMCR_T QSMCR;
    QTEST_T QTEST;
    QILR_T QILR;
    QIVR_T QIVR;
    word UNUSED1;
    SCCR0_T SCCR0;
    SCCR1_T SCCR1;
    SCSR_T SCSR;
    SCDR_T SCDR;
    word UNUSED2;
    word UNUSED3;
    PORTQS_T PORTQS;
    PQSPAR_T PQSPAR;
    DDRQS_T DDRQS;
    SPCR0_T SPCR0;
    SPCR1_T SPCR1;
    SPCR2_T SPCR2;
    SPCR3_T SPCR3;
    SPSR_T SPSR;
    word UNUSED4[0x70];
    word RX_RAM[0x10];
    word TX_RAM[0x10];
    CR_T COMMAND_RAM[0x10];
} QSM_T;


#endif
