/*
 * $Id: qsm_sci.c,v 1.6 2002/10/03 07:54:10 marobi Exp $
 *
 * serial communications interface
 *
 * The SCI allows i/o via a serial line to a host computer.
 *
 * Copyright (C) 2001 Doug Chapman
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <68332/asm.h>
#include <68332/qsm.h>
#include <68332/isr.h>
#include "qsm_regs.h"

#define SCIVEC 0x56     // needs to be in a header someplace

/* Not needed any more. MWP */
/*extern int vbraddr;*/

long int fcrystal = 32768L; /* anybody have a definition of this? */

#define Q_SIZE  160     /* how was this determined? arbitrary? */
#define RX  0
#define TX  1

extern QSM_T *QSM;

/* This is no longer needed either. MWP */
/*void sci_int(void);*/
void sci_handler(void);

typedef struct {
    int in;
    int out;
    char q[Q_SIZE + 10];
} queue_struct;

#ifndef TRUE
#define TRUE 1
#endif
#ifndef FALSE
#define FALSE 0
#endif

static queue_struct rxbuff = { 0, 0 };
static queue_struct txbuff = { 0, 0 };
static int sci_status;
static int xonoff = TRUE;


int havebyte(void)
{
    if (rxbuff.in != rxbuff.out)
    return 1;
    else
    return 0;
}


/*
 * qstat (private)
 *
 * Return the number of bytes in selected queue.
 */
int qstat(int which_queue)
{
    queue_struct *q;

    if (which_queue == RX)
    q = &rxbuff;
    else
    q = &txbuff;

    if (q->in > q->out) {
    return (q->in - q->out);
    } else if (q->in < q->out) {
    return (q->in + Q_SIZE - q->out);
    } else
    return 0;
}

/*
 * inbyte (public)
 *
 * Return 1 byte from the RX queue.  If no byte is available
 * return a null byte '\0'
 */
char inbyte(void)
{
    char rxbyte;

    if (rxbuff.in != rxbuff.out) {
    rxbyte = rxbuff.q[rxbuff.out];
    rxbuff.out++;
    if (rxbuff.out >= Q_SIZE)
        rxbuff.out = 0;
    } else {
    rxbyte = '\0';
    }

    if ((!xonoff) && (qstat(RX) < Q_SIZE / 4)) {
    QSM->SCCR1.BITS.RE = 1; /* RX enable */
    QSM->SCCR1.BITS.RIE = 1;    /* RX interrupt enable */
    }

    return rxbyte;
}


/*
 * outbyte
 *
 * Places a byte into the transmit buffer.  The actual
 * sending is done in the interrupt handler.
 *
 */
void outbyte(char txbyte)
{

    /* if the buffer is full wait until there is room */
    while (qstat(TX) > (Q_SIZE - 2));

    txbuff.q[txbuff.in] = txbyte;
    if (txbuff.in + 1 >= Q_SIZE) {
    txbuff.in = 0;
    } else {
    txbuff.in++;
    }

    QSM->SCCR1.BITS.TE = 1; /* TX enable */
    QSM->SCCR1.BITS.TIE = 1;    /* TX interrupt enable */
}

/*
 * see if the transmitter is busy sending bytes
 * or if data is left in the TX queue.
 */
int sendingbyte(void)
{
    if (txbuff.in != txbuff.out)
    return 1;
    return (QSM->SCSR.BITS.TC == 0);
}

void sciinit(long int baud_rate)
{
    long int fsystem;

    txbuff.in = 0;
    txbuff.out = 0;
    rxbuff.in = 0;
    rxbuff.out = 0;

    /*
     * we need something like install_handler(slot,function)
     */
    /* well here it is. MWP */
#if 0
    *(long *) (vbraddr + (SCIVEC + 0) * 4) = (long) sci_int;
    *(long *) (vbraddr + (SCIVEC + 1) * 4) = (long) sci_int;
#endif
    install_isr(SCIVEC+0, sci_handler);
    install_isr(SCIVEC+1, sci_handler);

    /* MJM: bugfix: #617762 (20021002) */
    fsystem = fcrystal * 4 * (((((*(word *) 0xfffa04) >> 8) & 0x3f) + 1)
                  << (((*(word *) 0xfffa04) >> 14) & 0x3));

    QSM->QSMCR.BITS.IARB = 7;   /* interrupt level 7 QSM */
    QSM->QSMCR.BITS.SUPV = 1;   /* QSM registers only accessible in supervisor mode */

    QSM->QIVR.BITS.INTV = SCIVEC;
    QSM->QILR.BITS.ILSC = 6;    /* interrupt level for SCI  = 6 */

    if (baud_rate > 0)
    QSM->SCCR0.BITS.SCBR = (fsystem / baud_rate / 16 + 1) / 2;

    QSM->SCCR1.BITS.TE = 1; /* TX enable */
    QSM->SCCR1.BITS.RE = 1; /* RX enable */
    QSM->SCCR1.BITS.RIE = 1;    /* RX interrupt enable */
    /* note, TIE is sent when we have something to transmit */

}



/*
 * sci_handler
 *
 * "C" part of the interrupt handler for tx/rx
 * The asm routine "sci_int" is caled on interrupt
 * which then calls sci_handler.
 */
void sci_handler(void)
{
    int scidata;
    SCSR_T status;

    status = QSM->SCSR;

    if (status.BITS.RDRF) { /* is there data in RX register? */
    scidata = QSM->SCDR.FULLWORD;

    if (status.FULLWORD & 0x00f) {  /* any of the error bits set? */
        sci_status = status.FULLWORD & 0x0f;
    } else {

        if ((rxbuff.in + 1 != rxbuff.out)
        && (rxbuff.in + 1 != rxbuff.out + Q_SIZE)) {

        rxbuff.q[rxbuff.in] = (char) scidata;
        rxbuff.in++;
        if (rxbuff.in >= Q_SIZE)
            rxbuff.in = 0;
        } else {
        ;       // buffer overrun code here
        }
    }
    } else if (status.BITS.OR) {    /* overrun error */
    scidata = QSM->SCDR.BITS.DATA;
    }

    if (status.BITS.TDRE) { /* TX data register empty */
    if ((xonoff) && (qstat(RX) > (Q_SIZE * 3) / 4)) {
        QSM->SCDR.BITS.DATA = 0x13; /* XOFF */
        xonoff = FALSE;
    } else if ((!xonoff) && (qstat(RX) < Q_SIZE / 4)) {
        QSM->SCDR.BITS.DATA = 0x11; /* XON */
        xonoff = TRUE;
    } else {
        if (txbuff.in != txbuff.out) {
        scidata = txbuff.q[txbuff.out];
        if (txbuff.out + 1 >= Q_SIZE)
            txbuff.out = 0;
        else
            txbuff.out++;

        QSM->SCDR.BITS.DATA = scidata;
        } else {
        // QSM->SCCR1.FULLWORD = 0x002c;
        QSM->SCCR1.BITS.TIE = 0;    /* shut off TX interrupt */
        }
    }
    }
}

/*This will be removed eventually too. MWP */
#if 0
/*
 * asm part of sci interrupt handler.
 * this just jumps to our C code sci_handler()
 */
asm(".global sci_int;sci_int:link %a6,#0");
asm("bsetb #1,0xfffa19");
asm("moveml %a6-%d0,-(%a7)");
asm("jsr sci_handler");
asm("moveml (%a7)+,%d0-%a6");
asm("bclrb #1,0xfffa19");
asm("unlk %a6;rte");
#endif
