/*
 * $Id: sim_regs.h,v 1.5 2002/10/03 01:22:16 dwalters Exp $
 * Registers for the System Integration Module
 *
 * Copyright (C) 2001 Doug Chapman 
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#ifndef __sim_regs_h__
#define __sim_regs_h__

#include <sys/types.h>
#include <68332/types.h>

#define SIM_BASE (0xfffffa00L)


typedef union {
	struct {
		uint16 EXOFF : 1;	/* external clock off */
		uint16 FRZSW : 1;	/* freeze software enable */
		uint16 FRZBM : 1;	/* freeze bus monitor enable */
		uint16 UNUSED0 : 1;
		uint16 RSVD : 1;
		uint16 UNUSED1 : 1;
		uint16 SHEN : 2;	/* show cycle enable */
		uint16 SUPV : 1;	/* supervisor/unrestricted data space */
		uint16 MM : 1;		/* module mapping */
		uint16 UNUSED2 : 2;
		uint16 IARB : 4;	/* interrupt arbitration id */
	} BITS;

	uint16 FULLWORD;
} SIMCR_T;


typedef uint16 SIMTR_T;		/* factor test only */

typedef union {
	struct {
		uint16 W : 1;	/* frequency control (VCO) */
		uint16 X : 1;	/* frequency control (prescaler) */
		uint16 Y : 6;	/* frequency control (counter) */
		uint16 EDIV : 1;	/* E clock divide rate */
		uint16 unused : 2;
		uint16 RSVD1 : 1;
		uint16 SLOCK : 1;	/* synthesizer lock flag */
		uint16 RSVD2 : 1;
		uint16 STSIM : 1; 	/* stop mode SIM clock */
		uint16 STEXT : 1;	/* stop mode external clock */
	} BITS;

	uint16 FULLWORD;
} SYNCR_T;

typedef union {
	struct {
		uint8 EXT : 1;		/* external reset */
		uint8 POW : 1;		/* power-up reset */
		uint8 SW : 1;		/* watchdog reset */
		uint8 HLT : 1;		/* halt monitor reset */
		uint8 unused : 1;
		uint8 RSVD : 1;
		uint8 SYS : 1;		/* system reset */
		uint8 TST : 1;		/* test submodule reset */
	} BITS;

	uint8 FULLWORD;
} RSR_T;


typedef uint16 SIMTRE_T; /* system test only */

typedef union {
	struct {
		uint8 DATA : 8;
	} BITS;

	uint8 FULLWORD;
} PORTE0_T;


typedef union {
	struct {
		uint8 DATA : 8;
	} BITS;

	uint8 FULLWORD;
} PORTE1_T;


typedef union {
	struct {
		uint8 DATA_DIR : 8;
	} BITS;

	uint8 FULLWORD;
} DDRE_T;

typedef union {
	struct {
		uint8 PIN_ASSIGN : 8;
	} BITS;

	uint8 FULLWORD;
} PEPAR_T;

typedef union {
	struct {
		uint8 DATA : 8;
	} BITS;

	uint8 FULLWORD;
} PORTF0_T;

typedef union {
	struct {
		uint8 DATA : 8;
	} BITS;

	uint8 FULLWORD;
} PORTF1_T;

typedef union {
	struct {
		uint8 DATA_DIR : 8;
	} BITS;

	uint8 FULLWORD;
} DDRF_T;

typedef union {
	struct {
		uint8 PIN_ASSIGN : 8;
	} BITS;

	uint8 FULLWORD;
} PFPAR_T;

typedef union {
	struct {
		uint8 SWE : 1;		/* software watchdog enable */
		uint8 SWP : 1;		/* software watchdog prescale */
		uint8 SWT : 2;		/* software watchdog timing */
		uint8 HME : 1;		/* halt monitor enable */
		uint8 BME : 1;		/* bus monitor external enable */
		uint8 BMT : 2;		/* bus monitor timing */
	} BITS;

	uint8 FULLWORD;
} SYPCR_T;

typedef union {
	struct {
		uint16 unused : 5;
		uint16 PIRQL : 3;	/* periodic interrupt request level */
		uint16 PIV : 8;		/* periodic interrupt vector */
	} BITS;

	uint16 FULLWORD;
} PICR_T;

typedef union {
	struct {
		uint16 unused : 7;
		uint16 PTP : 1;		/* periodic timer prescaler control */
		uint16 PITM : 8;	/* periodic timer modulus */
	} BITS;

	uint16 FULLWORD;
} PITR_T;

typedef union {
	struct {
		uint8 RESET : 8;
	} BITS;

	uint8 FULLWORD;
} SWSR_T;

typedef union {
	struct {
		uint16 unused : 9;
		uint16 PC6 : 1;
		uint16 PC5 : 1;
		uint16 PC4 : 1;
		uint16 PC3 : 1;
		uint16 PC2 : 1;
		uint16 PC1 : 1;
		uint16 PC0 : 1;
	} BITS;

	uint16 FULLWORD;
} PORTC_T;

typedef union {
	struct {
		uint16 unused : 2;
		uint16 CS5PA : 2;
		uint16 CS4PA : 2;
		uint16 CS3PA : 2;
		uint16 CS2PA : 2;
		uint16 CS1PA : 2;
		uint16 CS0PA : 2;
		uint16 CSBTPA : 2;
	} BITS;

	uint16 FULLWORD;
} CSPAR0_T;

typedef union {
	struct {
		uint16 unused : 6;
		uint16 CS10PA : 2;
		uint16 CS9PA : 2;
		uint16 CS8PA : 2;
		uint16 CS7PA : 2;
		uint16 CS6PA : 2;
	} BITS;

	uint16 FULLWORD;
} CSPAR1_T;

typedef union {
	struct {
		uint16 ADDR23 : 1;
		uint16 ADDR22 : 1;
		uint16 ADDR21 : 1;
		uint16 ADDR20 : 1;
		uint16 ADDR19 : 1;
		uint16 ADDR18 : 1;
		uint16 ADDR17 : 1;
		uint16 ADDR16 : 1;
		uint16 ADDR15 : 1;
		uint16 ADDR14 : 1;
		uint16 ADDR13 : 1;
		uint16 ADDR12 : 1;
		uint16 ADDR11 : 1;
		uint16 BLKSZ : 3;
	} BITS;

	uint16 FULLWORD;
} CSBAR_T;


typedef union {
	struct {
		uint16 MODE : 1;
		uint16 BYTE : 2;
		uint16 RW : 2;
		uint16 STRB : 1;
		uint16 DSACK : 4;
		uint16 SPACE : 2;
		uint16 IPL : 3;
		uint16 AVEC : 1;
	} BITS;

	uint16 FULLWORD;
} CSOR_T;


typedef struct {
	SIMCR_T SIMCR;
	SIMTR_T SIMTR;
	SYNCR_T SYNCR;
	uint8 pad0;
	RSR_T RSR;
	SIMTRE_T SIMTRE;
	uint16 unused0;
	uint16 unused1;
	uint16 unused2;
	uint8 pad2;
	PORTE0_T PORTE0;
	uint8 pad3;
	PORTE1_T PORTE1;
	uint8 pad4;
	DDRE_T DDRE;
	uint8 pad5;
	PEPAR_T PEPAR;
	uint8 pad6;
	PORTF0_T PORTF0;
	uint8 pad7;
	PORTF1_T PORTF1;
	uint8 pad8;
	DDRF_T DDRF;
	uint8 pad9;
	PFPAR_T PFPAR;
	uint8 pad10;
	SYPCR_T SYPCR;
	PICR_T PICR;
	PITR_T PITR;
	uint8 pad11;
	SWSR_T SWSR;
	uint16 unused3;
	uint16 unused4;
	uint16 unused5;
	uint16 unused6;
	uint16 TSTMSRA;
	uint16 TSTMSRB;
	uint16 TSTSC;
	uint16 TSTRC;
	uint16 CREG;
	uint16 DREG;
	uint16 unused7;
	uint16 unused8;
	PORTC_T PORTC;
	uint16 unused9;
	CSPAR0_T CSPAR0;
	CSPAR1_T CSPAR1;
	CSBAR_T CSBARBT;
	CSOR_T CSORBT;

	CSBAR_T CSBAR0;
	CSOR_T CSBOR0;
	CSBAR_T CSBAR1;
	CSOR_T CSBOR1;
	CSBAR_T CSBAR2;
	CSOR_T CSBOR2;
	CSBAR_T CSBAR3;
	CSOR_T CSBOR3;
	CSBAR_T CSBAR4;
	CSOR_T CSBOR4;
	CSBAR_T CSBAR5;
	CSOR_T CSBOR5;
	CSBAR_T CSBAR6;
	CSOR_T CSBOR6;
	CSBAR_T CSBAR7;
	CSOR_T CSBOR7;
	CSBAR_T CSBAR8;
	CSOR_T CSBOR8;
	CSBAR_T CSBAR9;
	CSOR_T CSBOR9;
	CSBAR_T CSBAR10;
	CSOR_T CSBOR10;
} SIM_T;


#endif

