/*
 * $Id: fqd.c,v 1.3 2003/12/07 07:23:20 dhylands Exp $
 *
 * Contains the functions to decode a pair of
 * quadrature encoded signals using the TPU function FQD.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <68332/fqd.h>


int16
fqd(TPUChannel* primaryChannel, TPUChannel* secondaryChannel)
{
  int16 value;

  if (primaryChannel->initialized == TPU_FUNC_FQD_A) {
    tpu_read_parameter_word(primaryChannel, TPU_PRAM_SLOT1, &value);

    return value;
  }
  else {
    tpu_set_CPR(primaryChannel, 0);  // turn off the TPU channels
    tpu_set_CPR(secondaryChannel, 0);
    tpu_set_CFSR(primaryChannel, 0x6); // set function code for FQD
    tpu_set_CFSR(secondaryChannel, 0x6);

    tpu_write_parameter_word(primaryChannel, TPU_PRAM_SLOT1, 0x00);
    tpu_write_parameter_word(primaryChannel, TPU_PRAM_SLOT4,
			     ((secondaryChannel->channel_num << 4) | 0x06));
    tpu_write_parameter_word(primaryChannel, TPU_PRAM_SLOT5,
			     ((primaryChannel->channel_num << 4) | 0x01));
    tpu_write_parameter_word(secondaryChannel, TPU_PRAM_SLOT4,
			     ((primaryChannel->channel_num << 4) | 0x06));
    tpu_write_parameter_word(secondaryChannel, TPU_PRAM_SLOT5,
			     ((primaryChannel->channel_num << 4) | 0x01));

    tpu_set_HSQR(primaryChannel, 0);
    tpu_set_HSQR(secondaryChannel, 1);

    tpu_set_HSRR(primaryChannel, 3);
    tpu_set_HSRR(secondaryChannel, 3);

    tpu_set_CPR(primaryChannel, 3); // turn on the TPU channels to high priority
    tpu_set_CPR(secondaryChannel, 3);

    primaryChannel->initialized = TPU_FUNC_FQD_A;
    secondaryChannel->initialized = TPU_FUNC_FQD_B;

    return 0;
  }
}
