/*
 * $Id: fqddi.c,v 1.4 2003/12/07 07:23:20 dhylands Exp $
 *
 * Contains the functions to provide a
 * discrete input using the TPU function FQD.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <68332/fqddi.h>


bool
fqddi(TPUChannel* handle)
{
  uint16 value;

  if (handle->initialized == TPU_FUNC_FQDDI) {
    tpu_read_parameter_word(handle, TPU_PRAM_SLOT3, &value);

    if (value == 0x8000) {
      return 1;
    }
    else {
      return 0;
    }
  }
  else {
    tpu_set_CPR(handle, 0);  // turn off the TPU channel
    tpu_set_CFSR(handle, 0x6); // set function code for FQD

    tpu_write_parameter_word(handle, TPU_PRAM_SLOT1, 0x00);
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT4,
			     ((handle->channel_num << 4) | 0x06));
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT5,
			     ((handle->channel_num << 4) | 0x01));

    tpu_set_HSQR(handle, 0);

    tpu_set_HSRR(handle, 3);

    tpu_set_CPR(handle, 1);  // turn on the TPU channel to low priority

    handle->initialized = TPU_FUNC_FQDDI;

    do {
      value = tpu_get_HSRR(handle);
    }
    while (value != 0);

    tpu_read_parameter_word(handle, TPU_PRAM_SLOT3, &value);

    if (value == 0x8000) {
      return 1;
    }
    else {
      return 0;
    }
  }
}
