/*
 * $Id: mcpwm.c,v 1.5 2003/12/07 07:23:20 dhylands Exp $
 *
 * This file contains the functions
 * used to manipulate the MCPWM TPU function.
 *
 * Copyright (C) 2001 Mike Panetta
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <stdlib.h>
#include <68332/tpu.h>
#include <68332/mcpwm.h>


MCPWMObjectP
mcpwm_init(uint16 tpu_num, uint16 chan, uint16 priority,
	   uint16 period, uint16 irqr)
{
	MCPWMObjectP mcpwm = NULL;
	TPUChannel* tpuChannel;
	uint16 tmp;
	
	mcpwm = malloc(sizeof (MCPWMObject));

	if (mcpwm == NULL)
		return NULL;

	if ((tpuChannel = tpu_request_channel(tpu_num, chan)) == NULL)
	{
		free(mcpwm);
		return NULL;
	}
	
	mcpwm->masterChannel = tpuChannel;
	mcpwm->priority      = priority;
	mcpwm->period		 = period;

	// Set the priority to 0 (disables the channel)
	tpu_set_CPR(mcpwm->masterChannel, 0);
	// Set the function to 0x7 (mcpwm)
	tpu_set_CFSR(mcpwm->masterChannel, 0x7);

	// Set the perameter RAM vars for the master channel
	tpu_write_parameter_word(mcpwm->masterChannel,
						TPU_PRAM_SLOT0, period);
	tmp = ((irqr << 8) & 0xFF00) | 0x00FF;
	tpu_write_parameter_word(mcpwm->masterChannel,
				 TPU_PRAM_SLOT1, tmp);
	tpu_write_parameter_word(mcpwm->masterChannel,
				 TPU_PRAM_SLOT4,
				 PRAM_ADDRESS(mcpwm->masterChannel->channel_num, TPU_PRAM_SLOT2));
	tpu_write_parameter_word(mcpwm->masterChannel,
				 TPU_PRAM_SLOT5,
				 PRAM_ADDRESS(mcpwm->masterChannel->channel_num, TPU_PRAM_SLOT3));

    tpuChannel->initialized = TPU_FUNC_MCPWM_MASTER;
	
	return mcpwm;
}

// vim: ts=4
// vim: sw=4
