/*
 * $Id: ptapulse.c,v 1.1 2003/10/30 02:09:27 dasmith Exp $
 *
 * Contains the functions to provide a servo
 * PWM signal using the TPU function QOM.
 *
 * Copyright (C) 2003 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <68332/ptapulse.h>

void
ptapulse_init(TPUChannel* handle, bool pulseLevel)
{
  if (!handle->initialized) {
    tpu_set_CPR(handle, 0);  // turn off the TPU channel
    tpu_set_CFSR(handle, 0xF); // set function code for PTA

    tpu_write_parameter_word(handle, TPU_PRAM_SLOT0, 0x000F);
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT1, 0x0100);
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT3, 0x0);
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT4, 0x0);
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT5, 0x0);

	if (pulseLevel) {
      tpu_set_HSQR(handle, 0);
	}
	else {
      tpu_set_HSQR(handle, 1);
	}

    tpu_set_HSRR(handle, 3);

    tpu_set_CPR(handle, 3);  // turn on the TPU channel to high priority

    handle->initialized = 1;
  }
}

uint32
ptapulse_result(TPUChannel* handle)
{
  uint16 hw, lw;
  uint32 result = 0;

  if (handle->initialized) {

    tpu_read_parameter_word(handle, TPU_PRAM_SLOT4, &hw);
    tpu_read_parameter_word(handle, TPU_PRAM_SLOT5, &lw);
    result = hw<<16 | lw;

    tpu_write_parameter_word(handle, TPU_PRAM_SLOT4, 0x0);
  }

  return result;
}
