/*
 * $Id: qomdo.c,v 1.3 2003/12/07 07:23:20 dhylands Exp $
 *
 * Contains the functions to provide a
 * discrete output using the TPU function QOM.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <68332/qomdo.h>


void
qomdo(TPUChannel* handle, bool state)
{
  if (handle->initialized == TPU_FUNC_QOMDO) {
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT0,
			     ((handle->channel_num << 4) | 0x04));
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT1, 0x00);

    // Load the final state after match
    // Use longest match time possible
    if (state) {
      tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, 0x8001);
      tpu_set_HSRR(handle, 3);
    }
    else {
      tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, 0x8000);
      tpu_set_HSRR(handle, 2);
    }
  }
  else {
    tpu_set_CPR(handle, 0);  // turn off the TPU channel
    tpu_set_CFSR(handle, 0xE); // set function code for QOM

    tpu_write_parameter_word(handle, TPU_PRAM_SLOT0,
			     ((handle->channel_num << 4) | 0x04));
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT1, 0x00);

    tpu_set_HSQR(handle, 0);

    // Load the final state after match
    // Use longest match time possible
    if (state) {
      tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, 0x8001);
      tpu_set_HSRR(handle, 3);
    }
    else {
      tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, 0x8000);
      tpu_set_HSRR(handle, 2);
    }

    tpu_set_CPR(handle, 1);  // turn on the TPU channel to low priority

    handle->initialized = TPU_FUNC_QOMDO;
  }
}
