/*
 * $Id: qompulse.c,v 1.2 2003/12/07 07:23:20 dhylands Exp $
 *
 * qompulse.h - Sets up a TPU channel to output a one-shot
 *              pulse using the TPU function QOM.
 *
 * Copyright (C) 2003 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <68332/qompulse.h>


void
qompulse(TPUChannel* handle, bool pulseLevel, uint16 pulseLength)
{
  if (handle->initialized != TPU_FUNC_QOMPULSE) {
    tpu_set_CPR(handle, 0);  // turn off the TPU channel
    tpu_set_CFSR(handle, 0xE); // set function code for QOM
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT0,
			     ((handle->channel_num << 4) | 0x04));
  }

  tpu_write_parameter_word(handle, TPU_PRAM_SLOT1, 0x00);

  if (pulseLevel)
  {
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, (pulseLength << 1));
    tpu_set_HSQR(handle, 0);
    tpu_set_HSRR(handle, 3);
  }
  else
  {
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, (pulseLength << 1 | 1));
    tpu_set_HSQR(handle, 0);
    tpu_set_HSRR(handle, 2);
  }

  if (!handle->initialized) {
    tpu_set_CPR(handle, 1);  // turn on the TPU channel to low priority
    handle->initialized = TPU_FUNC_QOMPULSE;
  }
}
