/*
 * $Id: qompwm.c,v 1.3 2003/12/07 07:23:20 dhylands Exp $
 *
 * Contains the functions to provide a
 * PWM signal using the TPU function QOM.
 *
 * Copyright (C) 2001 David A. Smith
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <68332/qompwm.h>


void
qompwm(TPUChannel* handle, uint16 hi_time, uint16 lo_time)
{
  if (handle->initialized == TPU_FUNC_QOMPWM) {
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, (hi_time << 1));
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT3, (lo_time << 1 | 1));
  }
  else {
    tpu_set_CPR(handle, 0);  // turn off the TPU channel
    tpu_set_CFSR(handle, 0xE); // set function code for QOM

    tpu_write_parameter_word(handle, TPU_PRAM_SLOT0,
			     ((handle->channel_num << 4) | 0x06));
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT1, 0x00);

    // Load the initial hi_time and lo_time
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT2, (hi_time << 1));
    tpu_write_parameter_word(handle, TPU_PRAM_SLOT3, (lo_time << 1 | 1));

    tpu_set_HSQR(handle, 2);
    tpu_set_HSRR(handle, 2);

    tpu_set_CPR(handle, 1);  // turn on the TPU channel to low priority

    handle->initialized = TPU_FUNC_QOMPWM;
  }
}
