/*
 * $Id: bitfield.c,v 1.1 2001/12/31 03:44:51 drc42 Exp $
 *
 * Test code to ensure bitfields are aligned as expected.
 *
 * Copyright (C) 2001 Doug Chapman
 * drc@drcproductions.com
 *
 * This library is distributed under the terms of the GNU Lesser General
 * Public License (LGPL).  You should have received a copy of the
 * license along with this library (LGPL.txt); if not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 */

#include <stdio.h>
#include <68332/qsm.h>
#include <68332/sim.h>
#include <68332/types.h>

typedef short int word;

#define BAUD_RATE 19200

typedef union {
    struct {
	uint16 highbyte : 8;
	uint16 lowbyte : 8;
    } BITS;
    uint16 FULLWORD;
} high_low_byte_t;

typedef union {
    struct {
	uint16 bits15_9 : 7;
	uint16 bits7_8 : 2;
	uint16 bits0_6 : 7;
    } BITS;
    uint16 FULLWORD;
} middle_bits_t;

typedef union {
    struct {
	uint8 upper_nibble : 4;
	uint8 lower_nibble : 4;
    } BITS;
    uint8 FULLWORD;
} char_bits_t;

int main(void)
{
    high_low_byte_t high_low_byte;
    middle_bits_t middle_bits;
    char_bits_t char_bits;

    set_processor_speed(CLOCK16MHZ);
    sciinit(BAUD_RATE);

    printf ("Test to verify bitfields are aligned as expected:\n");

    printf ("\thigh/low bytes: ");
    high_low_byte.FULLWORD = 0;
    high_low_byte.BITS.highbyte = 0xff;
    if (high_low_byte.FULLWORD == (uint16)(0xff << 8))
	printf ("PASS\n");
    else
	printf ("FAIL\n");

    printf ("\tmiddle bits: ");
    middle_bits.FULLWORD = 0;
    middle_bits.BITS.bits7_8 = 3;

    if (middle_bits.FULLWORD == (uint16)(3 << 7))
	printf ("PASS\n");
    else
	printf ("FAIL\n");

    printf ("\t8-bit bitfield: ");
    char_bits.FULLWORD = 0;
    char_bits.BITS.upper_nibble = 0xf;

    if (char_bits.FULLWORD == (uint8)(0xf << 4))
	printf ("PASS\n");
    else
	printf ("FAIL\n");

    /* make sure all data from printf's has been printed */
    while (sendingbyte());
    exit(0);
}
